Garfield.nn.GATEncoder
======================

.. currentmodule:: Garfield.nn

.. autoclass:: GATEncoder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GATEncoder.__init__
      ~GATEncoder.add_module
      ~GATEncoder.apply
      ~GATEncoder.bfloat16
      ~GATEncoder.buffers
      ~GATEncoder.children
      ~GATEncoder.compile
      ~GATEncoder.cpu
      ~GATEncoder.cuda
      ~GATEncoder.double
      ~GATEncoder.eval
      ~GATEncoder.extra_repr
      ~GATEncoder.float
      ~GATEncoder.forward
      ~GATEncoder.get_buffer
      ~GATEncoder.get_extra_state
      ~GATEncoder.get_parameter
      ~GATEncoder.get_submodule
      ~GATEncoder.half
      ~GATEncoder.ipu
      ~GATEncoder.load_state_dict
      ~GATEncoder.modules
      ~GATEncoder.named_buffers
      ~GATEncoder.named_children
      ~GATEncoder.named_modules
      ~GATEncoder.named_parameters
      ~GATEncoder.parameters
      ~GATEncoder.register_backward_hook
      ~GATEncoder.register_buffer
      ~GATEncoder.register_forward_hook
      ~GATEncoder.register_forward_pre_hook
      ~GATEncoder.register_full_backward_hook
      ~GATEncoder.register_full_backward_pre_hook
      ~GATEncoder.register_load_state_dict_post_hook
      ~GATEncoder.register_module
      ~GATEncoder.register_parameter
      ~GATEncoder.register_state_dict_pre_hook
      ~GATEncoder.requires_grad_
      ~GATEncoder.set_extra_state
      ~GATEncoder.share_memory
      ~GATEncoder.state_dict
      ~GATEncoder.to
      ~GATEncoder.to_empty
      ~GATEncoder.train
      ~GATEncoder.type
      ~GATEncoder.xpu
      ~GATEncoder.zero_grad
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GATEncoder.T_destination
      ~GATEncoder.call_super_init
      ~GATEncoder.dump_patches
      ~GATEncoder.training
   
   